AIOGramBot
==========

.. image:: https://img.shields.io/badge/telegram-aiogram-blue.svg?style=flat-square
   :target: https://t.me/aiogram_live
   :alt: [Telegram] aiogram live

.. image:: https://img.shields.io/pypi/v/aiogram.svg?style=flat-square
   :target: https://pypi.python.org/pypi/aiogram
   :alt: PyPi Package Version

.. image:: https://img.shields.io/pypi/status/aiogram.svg?style=flat-square
   :target: https://pypi.python.org/pypi/aiogram
   :alt: PyPi status

.. image:: https://img.shields.io/pypi/dm/aiogram.svg?style=flat-square
   :target: https://pypi.python.org/pypi/aiogram
   :alt: PyPi downloads

.. image:: https://img.shields.io/pypi/pyversions/aiogram.svg?style=flat-square
   :target: https://pypi.python.org/pypi/aiogram
   :alt: Supported python versions

.. image:: https://img.shields.io/badge/Telegram%20Bot%20API-5.0-blue.svg?style=flat-square&logo=telegram
   :target: https://core.telegram.org/bots/api
   :alt: Telegram Bot API

.. image:: https://img.shields.io/readthedocs/aiogram?style=flat-square
   :target: http://docs.aiogram.dev/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://img.shields.io/github/issues/aiogram/aiogram.svg?style=flat-square
   :target: https://github.com/aiogram/aiogram/issues
   :alt: Github issues

.. image:: https://img.shields.io/pypi/l/aiogram.svg?style=flat-square
   :target: https://opensource.org/licenses/MIT
   :alt: MIT License


**aiogram** is a pretty simple and fully asynchronous framework for `Telegram Bot API <https://core.telegram.org/bots/api>`_ written in Python 3.7 with `asyncio <https://docs.python.org/3/library/asyncio.html>`_ and `aiohttp <https://github.com/aio-libs/aiohttp>`_. It helps you to make your bots faster and simpler.

You can `read the docs here <http://docs.aiogram.dev/en/latest/>`_.

Official aiogram resources
--------------------------

- News: `@aiogram_live <https://t.me/aiogram_live>`_
- Community: `@aiogram <https://t.me/aiogram>`_
- Russian community: `@aiogram_ru <https://t.me/aiogram_ru>`_
- Pip: `aiogram <https://pypi.python.org/pypi/aiogram>`_
- Docs: `ReadTheDocs <http://docs.aiogram.dev>`_
- Source: `Github repo <https://github.com/aiogram/aiogram>`_
- Issues/Bug tracker: `Github issues tracker <https://github.com/aiogram/aiogram/issues>`_
- Test bot: `@aiogram_bot <https://t.me/aiogram_bot>`_
